=====
uxadt
=====

Cross-platform embedded representation for algebraic data types, values, and common operations.

.. image:: https://badge.fury.io/py/uxadt.svg
   :target: https://badge.fury.io/py/uxadt
   :alt: PyPI version and link.

This family of libraries supports a cross-platform embedded representation for algebraic data type (ADT) values, and platform-specific embedded programming abstractions for common operations (such as pattern matching) on algebraic data type values.
